import {
    Body,
    Controller,
    Get,
    HttpCode,
    HttpStatus,
    Post,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from "@nestjs/common";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { Constants } from "src/utils/constants";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { AboutPageHeaderCmsService } from "./about-page-header-cms.service";
import { UpdateAboutPageHeaderCmsDto } from "./dto/update-about-page-header-cms.dto";

@Controller({ path: "about-page-header-cms", version: Constants.API_VERSION_1 })

export class AboutPageHeaderCmsController {
    constructor(private readonly service: AboutPageHeaderCmsService) {
    }

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
      [
          { name: "image", maxCount: 1 }
      ]
    ))
    updateOrCreateData(
      @Body() dto: UpdateAboutPageHeaderCmsDto,
      @UploadedFiles() files: {
          image: UploadedMulterFileI,
      }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    // @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }
}
