import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateHomePageSectionFourSliderDto } from "./dto/create-home-page-section-four-slider.dto";
import { UpdateHomePageSectionFourSliderDto } from "./dto/update-home-page-section-four-slider.dto";
import { HomePageSectionFourSlider } from "./entities/home-page-section-four-slider.entity";

@EntityRepository(HomePageSectionFourSlider)
export class HomePageSectionFourSliderRepository extends Repository<HomePageSectionFourSlider> {
    async createEntity(dto: CreateHomePageSectionFourSliderDto): Promise<HomePageSectionFourSlider | Error> {
        try {
            const {
                title,
                type,
                buttonText,
                buttonLink,
                buttonTwoText,
                buttonTwoLink
            } = dto;
            const entity = this.create({
                title,
                type,
                buttonText,
                buttonLink,
                buttonTwoText,
                buttonTwoLink
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<HomePageSectionFourSlider | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateHomePageSectionFourSliderDto): Promise<HomePageSectionFourSlider | Error> {
        try {
            await this.update(id, {
                title: dto.title,
                type: dto.type,
                buttonText: dto.buttonText,
                buttonLink: dto.buttonLink,
                buttonTwoText: dto.buttonTwoText,
                buttonTwoLink: dto.buttonTwoLink
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<HomePageSectionFourSlider[] | Error> {
        try {
            return await this.find({
                where: { ...query, isDeleted: false }
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
              .createQueryBuilder()
              .update(HomePageSectionFourSlider)
              .set({ isDeleted: true })
              .where("id = :id", { id: id })
              .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}