import { EntityRepository, Repository } from "typeorm";
import { UpdateLandingPageCmsDto } from "./dto/update-landing-page-cms.dto";
import { LandingPageCms } from "./entities/landing-page-cms.entity";

@EntityRepository(LandingPageCms)
export class LandingPageCmsRepository extends Repository<LandingPageCms> {

    async createEntity(dto: UpdateLandingPageCmsDto): Promise<LandingPageCms | Error> {
        try {
            const entity = this.create({
                logo: dto.logo,
                title: dto.title,
                description: dto.description,
                questionTitle: dto.questionTitle,
                buttonOneText: dto.buttonOneText,
                buttonTwoText: dto.buttonTwoText,
                image: dto.image,
                pickUpPageTitle: dto.pickUpPageTitle,
                deliveryPageTitle: dto.deliveryPageTitle,
                searchBoxText: dto.searchBoxText,
                chooseStoreButtonText: dto.chooseStoreButtonText
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async updateEntity(dto: UpdateLandingPageCmsDto, id: string): Promise<LandingPageCms | Error> {
        try {
            await this.update(id, {
                logo: dto.logo,
                title: dto.title,
                description: dto.description,
                questionTitle: dto.questionTitle,
                buttonOneText: dto.buttonOneText,
                buttonTwoText: dto.buttonTwoText,
                image: dto.image,
                pickUpPageTitle: dto.pickUpPageTitle,
                deliveryPageTitle: dto.deliveryPageTitle,
                searchBoxText: dto.searchBoxText,
                chooseStoreButtonText: dto.chooseStoreButtonText
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findAll(): Promise<LandingPageCms[] | Error> {
        try {
            return await this.find({
                where: {
                    isDeleted: false
                }
            });
        } catch (e) {
            return e;
        }
    }
}