import { HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectRepository } from "@nestjs/typeorm";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { StepsSectionCmsRepository } from "./steps-section-cms.repository";
import { UpdateStepsSectionCmsDto } from "./dto/update-steps-section-cms.dto";
import { StepsSectionCmsEntity } from "./entities/steps-section-cms.entity";

@Injectable()
export class StepsSectionCmsService {
    constructor(
      @InjectRepository(StepsSectionCmsRepository)
      private readonly repository: StepsSectionCmsRepository,
      private readonly doSpaceService: DoSpacesService
    ) {
    }

    async updateOrCreateData(
      dto: UpdateStepsSectionCmsDto,
      files: {
          countOneImage: UploadedMulterFileI,
          countTwoImage: UploadedMulterFileI,
          countThreeImage: UploadedMulterFileI,
      }
    ): Promise<StepsSectionCmsEntity | Error> {
        if (files && files.countOneImage) {
            const countOneImage: any = await this.doSpaceService.uploadFile(files.countOneImage[0], "StepsSectionCms/");
            dto.countOneImage = countOneImage;
        }

        if (files && files.countTwoImage) {
            const countTwoImage: any = await this.doSpaceService.uploadFile(files.countTwoImage[0], "StepsSectionCms/");
            dto.countTwoImage = countTwoImage;
        }

        if (files && files.countThreeImage) {
            const countThreeImage: any = await this.doSpaceService.uploadFile(files.countThreeImage[0], "StepsSectionCms/");
            dto.countThreeImage = countThreeImage;
        }

        const isExists = await this.repository.find({ isDeleted: false });
        if (Object.keys(isExists).length === 0) {
            const data = await this.repository.createEntity(dto);
            if (!data) {
                throw new HttpException(
                  Constants.NOT_FOUND,
                  HttpStatus.NOT_FOUND
                );
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            let id = isExists[0].id;
            const data = await this.repository.updateEntity(dto, id);
            if (!data) {
                throw new HttpException(
                  Constants.UPDATE_FAILED,
                  HttpStatus.BAD_REQUEST
                );
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<StepsSectionCmsEntity[] | Error> {
        const data = await this.repository.findAll();
        if (!data) {
            throw new HttpException(
              Constants.NOT_FOUND,
              HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}