import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateCareerDepartmentDto } from "./dto/create-career-department.dto";
import { UpdateCareerDepartmentDto } from "./dto/update-career-department.dto";
import { CareerDepartment } from "./entities/career-department.entity";

@EntityRepository(CareerDepartment)
export class CareerDepartmentRepository extends Repository<CareerDepartment> {
    async createEntity(dto: CreateCareerDepartmentDto): Promise<CareerDepartment | Error> {
        try {
            const {
                name,
                logo,
                urlSlug
            } = dto;
            const entity = this.create({
                name,
                logo,
                urlSlug
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<CareerDepartment | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateCareerDepartmentDto): Promise<CareerDepartment | Error> {
        try {
            await this.update(id, {
                name: dto.name,
                logo: dto.logo,
                urlSlug: dto.urlSlug
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<CareerDepartment[] | Error> {
        try {
            return await this.find({
                where: { ...query, isDeleted: false }
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
              .createQueryBuilder()
              .update(CareerDepartment)
              .set({ isDeleted: true })
              .where("id = :id", { id: id })
              .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}