import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateCareerDto } from "./dto/create-career.dto";
import { UpdateCareerDto } from "./dto/update-career.dto";
import { Career } from "./entities/career.entity";

@EntityRepository(Career)
export class CareerRepository extends Repository<Career> {
    async createEntity(dto: CreateCareerDto): Promise<Career | Error> {
        try {
            const {
                jobType,
                title,
                location,
                description,
                salary,
                storeId,
                storeName,
                city,
                state,
                shortDescription
            } = dto;
            const entity = this.create({
                jobType,
                title,
                location,
                description,
                salary,
                storeId,
                storeName,
                city,
                state,
                shortDescription
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<Career | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateCareerDto): Promise<Career | Error> {
        try {
            await this.update(id, {
                jobType: dto.jobType,
                title: dto.title,
                location: dto.location,
                description: dto.description,
                salary: dto.salary,
                storeId: dto.storeId,
                storeName: dto.storeName,
                city: dto.city,
                state: dto.state,
                shortDescription: dto.shortDescription
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<Career[] | Error> {
        try {
            return await this.find({
                where: { ...query, isDeleted: false }
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
              .createQueryBuilder()
              .update(Career)
              .set({ isDeleted: true })
              .where("id = :id", { id: id })
              .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }

    async countByDepartmentName(name: string): Promise<any | Error> {
        try {
            return await this.count({
                where: {
                    departmentName: name,
                    isDeleted: false
                }
            });
        } catch (e) {
            return e;
        }
    }

    async totalCareerCount(): Promise<any | Error> {
        try {
            return await this.count({
                where: {
                    isDeleted: false
                }
            });
        } catch (e) {
            return e;
        }
    }
}