import {
    Body,
    Controller,
    Delete,
    Get,
    Param,
    Patch,
    Post,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from "@nestjs/common";
import { Constants } from "src/utils/constants";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { UploadedMulterFileI } from "../SpacesModule/SpacesService";
import { HomePageSectionEightService } from "./home-page-section-eight.service";
import { CreateHomePageSectionEightDto } from "./dto/create-home-page-section-eight.dto";
import { UpdateHomePageSectionEightDto } from "./dto/update-home-page-section-eight.dto";

@Controller({ path: "home-page-section-eight", version: Constants.API_VERSION_1 })

export class HomePageSectionEightController {
    constructor(private readonly service: HomePageSectionEightService) {
    }

    @Post()
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
      [
          { name: "image", maxCount: 1 }
      ]
    ))
    create(
      @Body() dto: CreateHomePageSectionEightDto,
      @UploadedFiles() files: {
          image: UploadedMulterFileI
      }
    ) {
        return this.service.create(dto, files);
    }

    @Get()
    // @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }

    @Get(":id")
    @UseGuards(AdminAuthGuard)
    findOne(@Param("id") id: string) {
        return this.service.findOne(id);
    }

    @Patch("/:id")
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
      [
          { name: "image", maxCount: 1 }
      ]
    ))
    update(
      @Param("id") id: string,
      @Body() dto: UpdateHomePageSectionEightDto,
      @UploadedFiles() files: {
          image: UploadedMulterFileI
      }
    ) {
        return this.service.update(id, dto, files);
    }

    @Delete(":id")
    @UseGuards(AdminAuthGuard)
    async remove(@Param("id") id: string) {
        return await this.service.remove(id);
    }
}
