import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreatePressReleaseDto } from "./dto/create-press-release.dto";
import { UpdatePressReleaseDto } from "./dto/update-press-release.dto";
import { PressRelease } from "./entities/press-release.entity";

@EntityRepository(PressRelease)
export class PressReleaseRepository extends Repository<PressRelease> {
    async createEntity(dto: CreatePressReleaseDto): Promise<PressRelease | Error> {
        try {
            const {
                title,
                description,
                category,
                image,
                urlSlug
            } = dto;
            const entity = this.create({
                title,
                description,
                category,
                image,
                urlSlug
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<PressRelease | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdatePressReleaseDto): Promise<PressRelease | Error> {
        try {
            await this.update(id, {
                title: dto.title,
                description: dto.description,
                category: dto.category,
                image: dto.image,
                urlSlug: dto.urlSlug
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<PressRelease[] | Error> {
        try {
            return await this.find({
                where: { ...query, isDeleted: false }
            });
        } catch (e) {
            return e;
        }
    }

    async findOneEntityBySlug(urlSlug: string): Promise<any | Error> {
        try {
            return await this.find({
                where: {
                    urlSlug: urlSlug
                }
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
              .createQueryBuilder()
              .update(PressRelease)
              .set({ isDeleted: true })
              .where("id = :id", { id: id })
              .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }

    async findLatestPressRelease(): Promise<any | Error> {
        try {
            return await this.find({
                where: {
                    isDeleted: false
                },
                order: {
                    createdAt: -1
                },
                take: 3
            });
        } catch (e) {
            return e;
        }
    }

    async countAllQuery(): Promise<any | Error> {
        try {
            return await this.count({
                where: {
                    isDeleted: false
                }
            });
        } catch (e) {
            return e;
        }
    }
}